aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xqa/rpc-tests/test_framework/mininode.py4
-rw-r--r--qa/rpc-tests/test_framework/scrypt_auxpow.py8
2 files changed, 6 insertions, 6 deletions
diff --git a/qa/rpc-tests/test_framework/mininode.py b/qa/rpc-tests/test_framework/mininode.py
index 89d0ae4f1..0b4b0dc1d 100755
--- a/qa/rpc-tests/test_framework/mininode.py
+++ b/qa/rpc-tests/test_framework/mininode.py
@@ -36,7 +36,7 @@ from threading import RLock
from threading import Thread
import logging
import copy
-import litecoin_scrypt
+import ltc_scrypt
from test_framework.siphash import siphash256
BIP0031_VERSION = 60000
@@ -583,7 +583,7 @@ class CBlockHeader(object):
r += struct.pack("<I", self.nNonce)
self.sha256 = uint256_from_str(hash256(r))
self.hash = encode(hash256(r)[::-1], 'hex_codec').decode('ascii')
- self.scrypt256 = uint256_from_str(litecoin_scrypt.getPoWHash(r))
+ self.scrypt256 = uint256_from_str(ltc_scrypt.getPoWHash(r))
def rehash(self):
self.sha256 = None
diff --git a/qa/rpc-tests/test_framework/scrypt_auxpow.py b/qa/rpc-tests/test_framework/scrypt_auxpow.py
index 7cb68ee03..a5f09dada 100644
--- a/qa/rpc-tests/test_framework/scrypt_auxpow.py
+++ b/qa/rpc-tests/test_framework/scrypt_auxpow.py
@@ -8,12 +8,12 @@
# solve an auxpow header and to generate auxpow blocks with scrypt.
# extends and modifies auxpow module by Daniel Kraft.
# This module requires a built and installed version of the litecoin_scrypt
# package, which can be downloaded from:
# https://pypi.python.org/packages/source/l/ltc_scrypt/ltc_scrypt-1.0.tar.gz
from .auxpow import *
-import litecoin_scrypt
+import ltc_scrypt
def computeAuxpowWithChainId (block, target, chainid, ok):
"""
@@ -70,7 +70,7 @@ def mineScryptAux (node, chainid, ok):
"""
auxblock = node.getauxblock ()
- target = reverseHex (auxblock['_target'])
+ target = reverseHex (auxblock['target'])
apow = computeAuxpowWithChainId (auxblock['hash'], target, chainid, ok)
res = node.getauxblock (auxblock['hash'], apow)
@@ -101,4 +101,4 @@ def getScryptPoW(hexData):
"""
data = bytes.fromhex(hexData)
- return reverseHex(litecoin_scrypt.getPoWHash(data).hex())
+ return reverseHex(ltc_scrypt.getPoWHash(data).hex())
@@ -8,12 +8,12 @@
# solve an auxpow header and to generate auxpow blocks with scrypt.
# extends and modifies auxpow module by Daniel Kraft.
-# This module requires a built and installed version of the litecoin_scrypt
+# This module requires a built and installed version of the ltc_scrypt
# package, which can be downloaded from:
# https://pypi.python.org/packages/source/l/ltc_scrypt/ltc_scrypt-1.0.tar.gz